/* Copyright (C) 2000/2001 sgop@users.sourceforge.net
   This is free software distributed under the terms of the
   GNU Public License.  See the file COPYING for details. */

void text_print_text(GtkText * widget, char *fmt, ...);
void port_dialog(char *message);
void download_dialog(char *filename, int mime);
void changes_dialog();
void server_dialog(char *title);
GtkWidget *create_info_win(char *text, char **buttons,
			   GtkSignalFunc * func);
void openfile_dialog(char *text);
void delete_dialog(char *text);
void resume_delete_dialog(char *text);
void new_version_dialog(char *text);
void check_version_dialog(char *text);
void info_dialog(char *text);
